@@ -911,7 +911,7 @@ g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, co
  * Returns a list of recipients of a chosen type from the MIME
  * Message.
  **/
-InternetAddressList *
+const InternetAddressList *
 g_mime_message_get_recipients (GMimeMessage *message, const char *type)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
@@ -1270,8 +1270,8 @@ handle_multipart_mixed (GMimeMultipart *multipart, gboolean want_plain, gboolean
 			/* if we haven't yet found a text part or if
                            it is a type we can understand and it is
                            the first of that type, save it */
-			if (!text_part || (!g_strcasecmp (type->subtype, "plain") && 
-					   g_strcasecmp (type->subtype, first_type->subtype) != 0)) {
+			if (!text_part || (!g_strcasecmp (type->subtype, "plain") && (first_type &&
+					   g_strcasecmp (type->subtype, first_type->subtype) != 0))) {
 				*is_html = !g_strcasecmp (type->subtype, "html");
 				text_part = mime_part;
 				first_type = type;
